==> nodegit-0.2.4.tgz: package/src/oid_shorten.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/oid_shorten.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitOidShorten::GitOidShorten(git_oid_shorten *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitOidShorten::~GitOidShorten() {
   }

  void GitOidShorten::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(New);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("OidShorten"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("OidShorten"), _constructor_template);
  }

  NAN_METHOD(GitOidShorten::New) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitOidShorten cannot be instantiated.");
     }

    GitOidShorten* object = new GitOidShorten(static_cast<git_oid_shorten *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitOidShorten::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitOidShorten::constructor_template)->NewInstance(2, argv));
  }

  git_oid_shorten *GitOidShorten::GetValue() {
    return this->raw;
  }

  git_oid_shorten **GitOidShorten::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitOidShorten::constructor_template;

==> nodegit-0.2.5.tgz: package/src/oid_shorten.cc <==
// This is a generated file, modify: generate/templates/class_content.cc.
#include <nan.h>
#include <string.h>

extern "C" {
  #include <git2.h>
 }


#include "../include/functions/copy.h"
#include "../include/macros.h"
#include "../include/oid_shorten.h"

 
#include <iostream>

using namespace std;
using namespace v8;
using namespace node;

  GitOidShorten::GitOidShorten(git_oid_shorten *raw, bool selfFreeing) {
    this->raw = raw;
    this->selfFreeing = selfFreeing;
  }

  GitOidShorten::~GitOidShorten() {
   }

  void GitOidShorten::InitializeComponent(Handle<v8::Object> target) {
    NanScope();

    Local<FunctionTemplate> tpl = NanNew<FunctionTemplate>(JSNewFunction);

    tpl->InstanceTemplate()->SetInternalFieldCount(1);
    tpl->SetClassName(NanNew<String>("OidShorten"));

  
    Local<Function> _constructor_template = tpl->GetFunction();
    NanAssignPersistent(constructor_template, _constructor_template);
    target->Set(NanNew<String>("OidShorten"), _constructor_template);
  }

  NAN_METHOD(GitOidShorten::JSNewFunction) {
    NanScope();

    if (args.Length() == 0 || !args[0]->IsExternal()) {
         return NanThrowError("A new GitOidShorten cannot be instantiated.");
     }

    GitOidShorten* object = new GitOidShorten(static_cast<git_oid_shorten *>(Handle<External>::Cast(args[0])->Value()), args[1]->BooleanValue());
    object->Wrap(args.This());

    NanReturnValue(args.This());
  }

  Handle<Value> GitOidShorten::New(void *raw, bool selfFreeing) {
    NanEscapableScope();
    Handle<Value> argv[2] = { NanNew<External>((void *)raw), NanNew<Boolean>(selfFreeing) };
    return NanEscapeScope(NanNew<Function>(GitOidShorten::constructor_template)->NewInstance(2, argv));
  }

  git_oid_shorten *GitOidShorten::GetValue() {
    return this->raw;
  }

  git_oid_shorten **GitOidShorten::GetRefValue() {
    return &this->raw;
  }

     Persistent<Function> GitOidShorten::constructor_template;
